/// <reference types="node" />
/** @internalapi */
/** This second comment is required for typedoc to recognise the WHOLE FILE as @internalapi */
import { IOAuth1HttpClient, IOAuth1State } from './OAuth1HttpClient';
import * as fs from 'fs';
import { AttachmentsResponse } from '../AccountingAPI-responses';
/**
 * TODO: Add support for the following keys:
 *
 * - PrivateKeyPassword
 */
export interface IXeroClientConfiguration {
    appType: 'public' | 'private' | 'partner';
    consumerKey: string;
    consumerSecret: string;
    privateKeyPath?: string;
    privateKeyString?: string;
    callbackUrl?: string;
}
/**
 * Options specific to the API in use
 */
export interface IApiConfiguration {
    tenantType?: string;
}
export interface IHttpClient {
    get<T>(endpoint: string, headers?: {
        [key: string]: string;
    }): Promise<T>;
    delete<T>(endpoint: string, headers?: {
        [key: string]: string;
    }): Promise<T>;
    put<T>(endpoint: string, body: object, headers?: {
        [key: string]: string;
    }): Promise<T>;
    post<T>(endpoint: string, body: object, headers?: {
        [key: string]: string;
    }): Promise<T>;
    writeUTF8ResponseToStream(endpoint: string, mimeType: string, writeStream: fs.WriteStream): Promise<void>;
    writeBinaryResponseToStream(endpoint: string, mimeType: string, writeStream: fs.WriteStream): Promise<void>;
    readStreamToRequest(endpoint: string, mimeType: string, size: number, readStream: fs.ReadStream): Promise<AttachmentsResponse>;
}
export declare abstract class BaseAPIClient {
    readonly oauth1Client: IOAuth1HttpClient;
    constructor(xeroConfig: IXeroClientConfiguration, authState?: IOAuth1State, apiConfig?: IApiConfiguration, oauth1Client?: IOAuth1HttpClient);
}
